Getting started
===============

The `README <https://github.com/ansible-community/ara/blob/master/README.md>`_ is the best place to get started.

It will tell you about:

- `what ara is <https://github.com/ansible-community/ara/blob/master/README.md#ara-records-ansible>`_
- `what it does <https://github.com/ansible-community/ara/blob/master/README.md#about-ara>`_
- `how it works <https://github.com/ansible-community/ara/blob/master/README.md#how-it-works>`_
- `what dependencies it needs <https://github.com/ansible-community/ara/blob/master/README.md#requirements>`_
- `how to get started <https://github.com/ansible-community/ara/blob/master/README.md#getting-started>`_
- `a live demo <https://github.com/ansible-community/ara/blob/master/README.md#live-demo>`_
- this documentation, the :ref:`troubleshooting guide <troubleshooting>` as well as :ref:`changelog and release notes <changelog-release-notes>`
- `where the project community hangs out <https://ara.recordsansible.org/community/>`_
- :ref:`how to contribute <contributing>`
- the `project blog <https://ara.recordsansible.org/blog/>`_ with development news, release note highlights, tips, benchmarks and more
- the `project authors and contributors <https://github.com/ansible-community/ara/graphs/contributors>`_
- the open source license (`GPLv3 <https://github.com/ansible-community/ara/blob/master/LICENSE>`_)

